***********************************************************************************
* Latin-TAXBEN - The Flexible Tax Simulator for Middle Income Countries
* Build 2012-1
*
* Program name: labor.do
* Program purpose: This program uses the individual change in the marginal and participation tax rates
* 			 and representative elasticities to calculate the behavioral and revenue impacts of
*			 changes in tax rates. Inc labor impact of indirect taxation (assuming no leisure-complements)

* Program note: This model is reduced form and analyses the impact on taxable income (as opposed to working decisions
* 		    directly. This means the elasticities are not underlying behavioral parameters but reflect
*		    also the structure of the tax system, opportunities to shift to informal work etc.

* Program created: 23 November 2010, by David Phillips
* Program updated: 28 November 2010, by David Phillips
* Program updated: 05 January 2011, by David Phillips
* Program updated: 29 May 2012, by David Phillips (based on MEXTAX 2010 Build)
*
** Nombre del programa: labor.do
** Objectivo del programa: Este programa utiliza los cambios en las tasas impositivas marginales y de participacion
**                          y elasticidades representativas para calcular los impactos de cambios en los impuestos
**                          en el comportamiento y en la recaudacion. Incluye el impacto de cambios en los impuestos
**                          indirectos en la oferta de trabajo (asumiendo que no hay bienes complementarios con el ocio)
**
** Programa creado: 23 Noviembre 2010, por David Phillips
** Programa actualizado: 28 Noviembre 2010, por David Phillips
** Programa actualizado: 05 Enero 2011, por David Phillips
** Programa actualizado: 29 May 2012, por David Phillips
***********************************************************************************
cap log close

*************************************************************************
**************** EXPENDITURE AVERAGE INDIRECT TAX RATE*******************
**************TO BE USED TO CALCULATE BOTH PTR AND MTR ******************
*************************************************************************

use "$out//indir_$sys1", clear

keep folioviv foliohog numren ieps_t iva_t piva

gen indirtax$sys1 = (ieps_tot$sys1+iva_tot$sys1)/piva$sys1

foreach Y in $sys2 $sys3 {

	sort folioviv foliohog numren
	merge folioviv foliohog numren using "$out//indir_`Y'", keep(folioviv foliohog numren ieps_t* iva_t* piva*)
	drop _merge

	gen indirtax`Y' = (ieps_tot`Y'+iva_tot`Y')/piva`Y'

}

	drop numren

	sort folioviv foliohog

	save "$out//labor_cons", replace


***********************************************************************
**************** INCOME TAX AND SOC SEC PTR AND MTR *******************
***********************************************************************

use "$out//dir_$sys1", clear

gen ptr_$sys1 = (inctax_$sys1+socsec_$sys1)/gross_$sys1
gen mtr_$sys1 = taxrate_$sys1 + socrate_$sys1

foreach Y in $sys2 $sys3 {

	sort folioviv foliohog numren
	merge folioviv foliohog numren using "$out//dir_`Y'", keep(folioviv foliohog numren  gross* inctax* taxrate* socsec* socrate*)
	drop _merge

	gen ptr_`Y' = (inctax_`Y'+socsec_`Y')/gross_`Y'
	gen mtr_`Y' = taxrate_`Y' + socrate_`Y'

}

	sort folioviv foliohog

	merge folioviv foliohog using "$out//labor_cons"

	tab _merge
	drop _merge

foreach Y in $sys1 $sys2 $sys3 {

	replace ptr_`Y' = (ptr_`Y'+indirtax`Y')/(1+ indirtax`Y')
	replace mtr_`Y' = (mtr_`Y'+indirtax`Y')/(1+ indirtax`Y')

	replace ptr_`Y' = . if gross_`Y'==.
	replace mtr_`Y' = . if gross_`Y'==.

}

sort folioviv foliohog numren

merge folioviv foliohog numren using "$in\\$indata_ad", keep(folioviv foliohog numren sex age education)

tab _merge
drop _merge

sort folioviv foliohog

merge folioviv foliohog using "$in\\$indata_hh", keep(folioviv foliohog factor menores hhtype)

order folioviv foliohog numren ptr_* mtr_*

********************************************************************
**************** LABOUR SUPPLY EFFECTS ESTIMATED *******************
********************************************************************

keep if gross_$sys1>0 & gross_$sys1!=.

xtile percgross = gross_$sys1 [fw=factor], nq(100)

** FIRST SET ELAST
destring sex, replace
destring menores, replace
gen hourselast = 0.05
replace hourselast = 0.1 if sex==2 & menores>1
replace hourselast = 0.1 if percgross>90
replace hourselast = 0.2 if percgross==100

gen partelast = 0.05
replace partelast =  partelast*2 if percgross>40 & percgross<=60
replace partelast =  partelast*3 if percgross>20 & percgross<=40
replace partelast =  partelast*4 if percgross>0 & percgross<=20
replace partelast =  partelast*2 if menores>1 & sex==2

sum hourselast partelast [fw=factor] if gross_$sys1>0

***** DO PROPORTIONAL CHANGES IN 'HOURS' AND 'PARTICIPATION' *****

** REFORM 1

	gen double newgross$sys2 = gross_$sys1*(((1-mtr_$sys2)/(1-mtr_$sys1))^hourselast)
	gen double change_p$sys2 = ((1-ptr_$sys2)/(1-ptr_$sys1))^partelast

** REFORM 2

	gen double newgross$sys3 = gross_$sys1*(((1-mtr_$sys3)/(1-mtr_$sys1))^hourselast)
	gen double change_p$sys3 = 1*((1-ptr_$sys3)/(1-ptr_$sys1))^partelast


***** IMPACT ON EARNINGS *****

** REFORM 1

	gen double wnewgross$sys2 = change_p$sys2*newgross$sys2
	gen double extra_int$sys2 = newgross$sys2 - gross_$sys1
	gen double extra_ext$sys2 = (change_p$sys2-1)*gross_$sys1
	gen double extra_inter$sys2 = (change_p$sys2-1)*(newgross$sys2 - gross_$sys1)
	gen double extra_tot$sys2 = wnewgross$sys2 - gross_$sys1

** REFORM 2

	gen double wnewgross$sys3 = change_p$sys3*newgross$sys3
	gen double extra_int$sys3 = newgross$sys3 - gross_$sys1
	gen double extra_ext$sys3 = (change_p$sys3-1)*gross_$sys1
	gen double extra_inter$sys3 = (change_p$sys3-1)*(newgross$sys3 - gross_$sys1)
	gen double extra_tot$sys3 = wnewgross$sys3 - gross_$sys1


***** IMPACT ON REVENUES *****
* assumes mtr is constant over range of change

** REFORM 1

	gen extratax_i$sys2 = mtr_$sys2*extra_int$sys2
	gen double extratax_ex$sys2 = (change_p$sys2-1)*(ptr_$sys2*gross_$sys1)
	gen double extratax_int$sys2 = (change_p$sys2-1)*(newgross$sys2-gross_$sys1)*mtr_$sys2
	gen double extratax_tot$sys2 = extratax_i$sys2+ extratax_ex$sys2+  extratax_int$sys2

** REFORM 2

	gen extratax_i$sys3 = mtr_$sys3*extra_int$sys3
	gen double extratax_ex$sys3 = (change_p$sys3-1)*(ptr_$sys3*gross_$sys1)
	gen double extratax_int$sys3 = (change_p$sys3-1)*(newgross$sys3-gross_$sys1)*mtr_$sys3
	gen double extratax_tot$sys3 = extratax_i$sys3+ extratax_ex$sys3+  extratax_int$sys3


***** CREATE SUMMARY STATISTICS *****

* Does it separately by types of education, by age of worker, by gender and by household type

gen agegroup = 1
replace agegroup = 2 if age>17
replace agegroup = 3 if age>24
replace agegroup = 4 if age>34
replace agegroup = 5 if age>49
replace agegroup = 6 if age>64

label def agegroup 1 "Under 18" 2 "18 - 24" 3 "25 - 34" 4 "35 - 49" 5 "50 - 64" 6 "65+"
label val agegroup agegroup

gen educgroup = 1
replace educgroup = 2 if education==2
replace educgroup = 3 if education==3
replace educgroup = 4 if education==4 | education==8 | education==9
replace educgroup = 5 if education==5 | education==6 | education==7

label def educgroup 1 "None or Preschool" 2 "Primary school" 3 "Secondary School" 4 "Degree or Advanced Degree" 5 "Commercial, Industrial or Professional"
label val educgroup educgroup

label def sex 1 "Male" 2 "Female"
label val sex sex



foreach x in $sys2 $sys3 {

	egen totalini_agegroup`x'   = sum(gross_$sys1*factor), by(agegroup)
	egen totalini_educgroup`x'  = sum(gross_$sys1*factor), by(educgroup)
	egen totalini_sex`x'   = sum(gross_$sys1*factor), by(sex)
	egen totalini_hhtype`x'= sum(gross_$sys1*factor), by(hhtype)
	egen totalini_num`x'	     = sum(gross_$sys1*factor)

	egen totalinc_agegroup`x'   = sum(extra_tot`x'*factor), by(agegroup)
	egen totalinc_educgroup`x'  = sum(extra_tot`x'*factor), by(educgroup)
	egen totalinc_sex`x'   = sum(extra_tot`x'*factor), by(sex)
	egen totalinc_hhtype`x'= sum(extra_tot`x'*factor), by(hhtype)
	egen totalinc_num`x'	     = sum(extra_tot`x'*factor)

	egen totaltax_agegroup`x'   = sum(extratax_tot`x'*factor), by(agegroup)
	egen totaltax_educgroup`x'  = sum(extratax_tot`x'*factor), by(educgroup)
	egen totaltax_sex`x'   = sum(extratax_tot`x'*factor), by(sex)
	egen totaltax_hhtype`x'= sum(extratax_tot`x'*factor), by(hhtype)
	egen totaltax_num`x'	     = sum(extratax_tot`x'*factor)

}

qui {

local age "agegroup"
local educ "educgroup"
local sexy "sex"
local nu "num"

gen num = 1

foreach y in agegroup educgroup sex hhtype num {

	foreach x in $sys2 $sys3 {

		tabstat totalini_`y'`x' totalinc_`y'`x' totaltax_`y'`x' [fw=factor], stats(mean) f(%20.0fc) by(`y') save

		if ("`y'" == "`age'") {

			matrix maa`y'_`x' = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5), r(Stat6))

		}

		if ("`y'" == "`educ'") {

			matrix maa`y'_`x' = (r(Stat1), r(Stat2), r(Stat3), r(Stat4), r(Stat5))

		}

		if ("`y'" == "`sexy'") {

			matrix maa`y'_`x' = (r(Stat1), r(Stat2))

		}

		if ("`y'" == "`nu'") {

			matrix maa`y'_`x' = (r(Stat1))

		}

	}	/* end x */
} 		/* end y */
} 		/* end qui */

capture program drop log_labor
program define log_labor

set logtype text
log using "$out//$logfilelabor", replace

foreach x in $sys2 $sys3 {

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~55s "Labor supply effects of reforms by age group for system " `x'  /*
				*/ _newline "" /*
				*/ _newline " Age Group  {c |}" %~15s "         Gross Income" %~10s "           Change in Income" %~14s "       Change in Tax" /*
				*/ _newline "{hline 12}{c +}{hline 72}"  /*
				*/ _newline as text " Under 18   {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,1] "      $" %15.0fc maaagegroup_`x'[1,2] "      $" %15.0fc maaagegroup_`x'[1,3] /*
				*/ _newline as text " 18 - 24    {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,4] "      $" %15.0fc maaagegroup_`x'[1,5] "      $" %15.0fc maaagegroup_`x'[1,6] /*
				*/ _newline as text " 25 - 34    {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,7] "      $" %15.0fc maaagegroup_`x'[1,8] "      $" %15.0fc maaagegroup_`x'[1,9] /*
				*/ _newline as text " 35 - 49    {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,10] "      $" %15.0fc maaagegroup_`x'[1,11] "      $" %15.0fc maaagegroup_`x'[1,12] /*
				*/ _newline as text " 49 - 64    {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,13] "      $" %15.0fc maaagegroup_`x'[1,14] "      $" %15.0fc maaagegroup_`x'[1,15] /*
				*/ _newline as text " 65 or Over {c |}" as result "     $" %18.0fc maaagegroup_`x'[1,16] "      $" %15.0fc maaagegroup_`x'[1,17] "      $" %15.0fc maaagegroup_`x'[1,18] /*
				*/ _newline as text "{hline 12}{c +}{hline 72}"

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~55s "Labor supply effects of reforms by educ group for system " `x' /*
				*/ _newline "" /*
				*/ _newline " Educ Group              {c |}" %~15s "         Gross Income" %~10s "           Change in Income" %~14s "       Change in Tax" /*
				*/ _newline "{hline 25}{c +}{hline 72}"  /*
				*/ _newline as text " None or Preschool       {c |}" as result "     $" %18.0fc maaeducgroup_`x'[1,1] "      $" %15.0fc maaeducgroup_`x'[1,2] "      $" %15.0fc maaeducgroup_`x'[1,3] /*
				*/ _newline as text " Primary School          {c |}" as result "     $" %18.0fc maaeducgroup_`x'[1,4] "      $" %15.0fc maaeducgroup_`x'[1,5] "      $" %15.0fc maaeducgroup_`x'[1,6] /*
				*/ _newline as text " Secondary School        {c |}" as result "     $" %18.0fc maaeducgroup_`x'[1,7] "      $" %15.0fc maaeducgroup_`x'[1,8] "      $" %15.0fc maaeducgroup_`x'[1,9] /*
				*/ _newline as text " Degree (inc. PhD)       {c |}" as result "     $" %18.0fc maaeducgroup_`x'[1,10] "      $" %15.0fc maaeducgroup_`x'[1,11] "      $" %15.0fc maaeducgroup_`x'[1,12] /*
				*/ _newline as text " Commercial/Professional {c |}" as result "     $" %18.0fc maaeducgroup_`x'[1,13] "      $" %15.0fc maaeducgroup_`x'[1,14] "      $" %15.0fc maaeducgroup_`x'[1,15] /*
				*/ _newline as text "{hline 25}{c +}{hline 72}"

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~55s "Labor supply effects of reforms by age group for system " `xx' /*
				*/ _newline "" /*
				*/ _newline " Sex        {c |}" %~15s "         Gross Income" %~10s "           Change in Income" %~14s "       Change in Tax" /*
				*/ _newline "{hline 12}{c +}{hline 72}"  /*
				*/ _newline as text " Male       {c |}" as result "     $" %18.0fc maasex_`x'[1,1] "      $" %15.0fc maasex_`x'[1,2] "      $" %15.0fc maasex_`x'[1,3] /*
				*/ _newline as text " Female     {c |}" as result "     $" %18.0fc maasex_`x'[1,4] "      $" %15.0fc maasex_`x'[1,5] "      $" %15.0fc maasex_`x'[1,6] /*
				*/ _newline as text "{hline 12}{c +}{hline 72}"

			di as text "" /*
				*/ _newline "" /*
				*/ _newline %~55s "Labor supply effects of reforms by age group for system " `xx' /*
				*/ _newline "" /*
				*/ _newline " Total      {c |}" %~15s "         Gross Income" %~10s "           Change in Income" %~14s "       Change in Tax" /*
				*/ _newline "{hline 12}{c +}{hline 72}"  /*
				*/ _newline as text " Total      {c |}" as result "     $" %18.0fc maanum_`x'[1,1] "      $" %15.0fc maanum_`x'[1,2] "      $" %15.0fc maanum_`x'[1,3] /*
				*/ _newline as text "{hline 12}{c +}{hline 72}" /*
				*/ _newline as text "{hline 12}{c -}{hline 100}"
				}
log close

end

log_labor

exit
